@@ -1,5 +1,5 @@
 package Job::Machine::DB;
-$Job::Machine::DB::VERSION = '0.23';
+$Job::Machine::DB::VERSION = '0.24';
 use strict;
 use warnings;
 use Carp qw/croak confess/;
@@ -464,7 +464,9 @@ sub where_clause {
 
 sub order_by {
 	my ($self, $order) = @_;
-	my $order_by = join(',', ("$_") x keys @$order);
+	return unless ref $order eq 'HASH';
+
+	my $order_by = join(',', ("$_") x keys %$order);
 	$order_by = "ORDER BY $order_by" if $order_by;
 	return $order_by;
 }
@@ -483,7 +485,7 @@ Job::Machine::DB
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 NAME
 
